TgradeApp

Struct TgradeApp 

pub struct TgradeApp(/* private fields */);

Implementations

Source

impl TgradeApp

pub fn new(owner: &str) -> Self

pub fn new_genesis(owner: &str) -> Self

pub fn block_info(&self) -> BlockInfo

pub fn promote(&mut self, owner: &str, contract: &str) -> AnyResult<AppResponse>

pub fn back_to_genesis(&mut self)

This reverses to genesis (based on current time/height)

pub fn advance_blocks(&mut self, blocks: u64)

This advances BlockInfo by given number of blocks. It does not do any callbacks, but keeps the ratio of seconds/blokc

pub fn advance_seconds(&mut self, seconds: u64)

This advances BlockInfo by given number of seconds. It does not do any callbacks, but keeps the ratio of seconds/blokc

pub fn next_block(&mut self) -> AnyResult<Option<ValidatorDiff>>

next_block will call the end_blocker, increment block info 1 height and 5 seconds, and then call the begin_blocker (with no evidence) in the next block. It returns the validator diff if any.

Simple iterator when you don’t care too much about the details and just want to simulate forward motion.

pub fn with_privilege(&self, requested: Privilege) -> AnyResult<Vec<Addr>>

Returns a list of all contracts that have the requested privilege

pub fn begin_block( &mut self, evidence: Vec<Evidence>, ) -> AnyResult<Vec<AppResponse>>

Make the BeginBlock sudo callback on all contracts that have registered with the BeginBlocker Privilege

pub fn end_block( &mut self, ) -> AnyResult<(Vec<AppResponse>, Option<ValidatorDiff>)>

Make the EndBlock sudo callback on all contracts that have registered with the EndBlocker Privilege. Then makes the EndWithValidatorUpdate callback on any registered valset_updater.

Methods from Deref<Target = TgradeAppWrapped>

pub fn init_modules<F, T>(&mut self, init_fn: F) -> T
where F: FnOnce(&mut Router<BankT, CustomT, WasmT, StakingT, DistrT, IbcT, GovT>, &dyn Api, &mut dyn Storage) -> T,

pub fn read_module<F, T>(&self, query_fn: F) -> T
where F: FnOnce(&Router<BankT, CustomT, WasmT, StakingT, DistrT, IbcT, GovT>, &dyn Api, &dyn Storage) -> T,

pub fn store_code( &mut self, code: Box<dyn Contract<<CustomT as Module>::ExecT, <CustomT as Module>::QueryT>>, ) -> u64

This registers contract code (like uploading wasm bytecode on a chain), so it can later be used to instantiate a contract.

pub fn contract_data(&self, address: &Addr) -> Result<ContractData, Error>

This allows to get ContractData for specific contract

pub fn dump_wasm_raw(&self, address: &Addr) -> Vec<(Vec<u8>, Vec<u8>)>

This gets a raw state dump of all key-values held by a given contract

pub fn set_block(&mut self, block: BlockInfo)

pub fn update_block<F>(&mut self, action: F)
where F: Fn(&mut BlockInfo),

pub fn block_info(&self) -> BlockInfo

Returns a copy of the current block_info

pub fn wrap(&self) -> QuerierWrapper<'_, <CustomT as Module>::QueryT>

Simple helper so we get access to all the QuerierWrapper helpers, eg. wrap().query_wasm_smart, query_all_balances, …

pub fn execute_multi( &mut self, sender: Addr, msgs: Vec<CosmosMsg<<CustomT as Module>::ExecT>>, ) -> Result<Vec<AppResponse>, Error>

Runs multiple CosmosMsg in one atomic operation. This will create a cache before the execution, so no state changes are persisted if any of them return an error. But all writes are persisted on success.

pub fn wasm_sudo<T, U>( &mut self, contract_addr: U, msg: &T, ) -> Result<AppResponse, Error>
where T: Serialize, U: Into<Addr>,

Call a smart contract in “sudo” mode. This will create a cache before the execution, so no state changes are persisted if this returns an error, but all are persisted on success.

pub fn sudo(&mut self, msg: SudoMsg) -> Result<AppResponse, Error>

Runs arbitrary SudoMsg. This will create a cache before the execution, so no state changes are persisted if this returns an error, but all are persisted on success.